@@ -315,8 +315,7 @@ get_pid(const char *pidfile, bool quiet)
 
 	if ((fp = fopen(pidfile, "r")) == NULL) {
 		if (!quiet)
-			eerror("%s: fopen `%s': %s",
-			    applet, pidfile, strerror(errno));
+			eerror("%s: fopen `%s': %s", applet, pidfile, strerror(errno));
 		return -1;
 	}
 
@@ -355,8 +354,7 @@ do_stop(const char *exec, const char *const *argv,
 	LIST_FOREACH_SAFE(pi, pids, entries, np) {
 		if (test) {
 			if (!quiet)
-				einfo("Would send signal %d to PID %d",
-				    sig, pi->pid);
+				einfo("Would send signal %d to PID %d", sig, pi->pid);
 			nkilled++;
 		} else {
 			if (verbose)
@@ -417,7 +415,7 @@ run_stop_schedule(const char *exec, const char *const *argv,
 	}
 
 	if (pidfile) {
-		pid = get_pid(pidfile, quiet);
+		pid = get_pid(pidfile, false);
 		if (pid == -1)
 			return 0;
 	}
@@ -436,9 +434,7 @@ run_stop_schedule(const char *exec, const char *const *argv,
 				if (tkilled == 0) {
 					if (progressed)
 						printf("\n");
-					if (! quiet)
-						eerror("%s: no matching "
-						    "processes found", applet);
+						eerror("%s: no matching processes found", applet);
 				}
 				return tkilled;
 			}
@@ -508,14 +504,10 @@ run_stop_schedule(const char *exec, const char *const *argv,
 
 	if (progressed)
 		printf("\n");
-	if (! quiet) {
-		if (nrunning == 1)
-			eerror("%s: %d process refused to stop",
-			    applet, nrunning);
-		else
-			eerror("%s: %d process(es) refused to stop",
-			    applet, nrunning);
-	}
+	if (nrunning == 1)
+		eerror("%s: %d process refused to stop", applet, nrunning);
+	else
+		eerror("%s: %d process(es) refused to stop", applet, nrunning);
 
 	return -nrunning;
 }
@@ -1295,7 +1287,7 @@ start_stop_daemon(int argc, char **argv)
 		/* We don't redirect stdin as some daemons may need it */
 		if (background || quiet || redirect_stdout)
 			dup2(stdout_fd, STDOUT_FILENO);
-		if (background || quiet || redirect_stderr)
+		if (background || redirect_stderr)
 			dup2(stderr_fd, STDERR_FILENO);
 
 		for (i = getdtablesize() - 1; i >= 3; --i)
@@ -1326,12 +1318,9 @@ start_stop_daemon(int argc, char **argv)
 				return -1;
 			}
 		} while (!WIFEXITED(i) && !WIFSIGNALED(i));
-		if (!WIFEXITED(i) || WEXITSTATUS(i) != 0) {
-			if (!quiet)
-				eerrorx("%s: failed to start `%s'",
-				    applet, exec);
-			exit(EXIT_FAILURE);
-		}
+		if (!WIFEXITED(i) || WEXITSTATUS(i) != 0)
+			eerrorx("%s: failed to start `%s'", applet, exec);
+
 		pid = spid;
 	}
 
@@ -1365,7 +1354,7 @@ start_stop_daemon(int argc, char **argv)
 				alive = true;
 		} else {
 			if (pidfile) {
-				pid = get_pid(pidfile, true);
+				pid = get_pid(pidfile, false);
 				if (pid == -1) {
 					eerrorx("%s: did not "
 					    "create a valid"
